<?php

$LANG = array(

#header.php
'MENU'					=> 'Meniu',
'HOME'					=> 'Home',
'GOTO_CONTENT'			=> 'La con&#355;inut',
'GOTO_MENU'				=> 'La meniu',
'COMMENTS_RSS_FEEDS'	=> 'Flux RSS Comentarii',
'COMMENTS'				=> 'Comentarii',
'ARTICLES_RSS_FEEDS'	=> 'Flux RSS Articole',
'ARTICLES'				=> 'Articole',

# sidebar.php
'CATEGORIES' 			=> 'Categorii',
'LATEST_ARTICLES'		=> 'Ultimile Articole',
'LATEST_COMMENTS'		=> 'Ultimile Comentarii',
'ARCHIVES'				=> 'Arhiva',

# footer.php
'POWERED_BY'			=> 'Realizat de',
'PLUXML_DESCRIPTION'	=> 'Descriere',
'IN'					=> '&#238;n',
'ADMINISTRATION'		=> 'Administra&#355;ia',
'GOTO_TOP'				=> 'Dute sus',
'TOP'					=> 'Sus',

# erreur.php
'ERROR'					=> 'A survenit o eroare',
'BACKTO_HOME'			=> '&#206;napoi la Pagina Principal&#259;',

# common
'WRITTEN_BY'			=> 'Scris de',
'CLASSIFIED_IN'			=> 'Postat &#238;n',
'TAGS'					=> 'Etichete',

# commentaires.php
'SAID'					=> 'a spus',
'WRITE_A_COMMENT'		=> 'Adaug&#259; un comentariu',
'NAME'					=> 'Nume',
'WEBSITE'				=> 'Site (nu e obligatoriu)',
'EMAIL'					=> 'E-mail (nu e obligatoriu)',
'COMMENT'				=> 'Comentariul',
'CLEAR'					=> 'Cur&#259;&#354;&#259;',
'SEND'					=> 'Trimite',
'COMMENTS_CLOSED'		=> 'Comentariile sunt &#238;nchise',
'ANTISPAM_WARNING'		=> 'Verificare anti-spam',

'REPLY'					=> 'Răspuns',
'REPLY_TO'				=> 'Răspuns',
'CANCEL'				=> 'Anulare',

);

?>